namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(500)]                                          
    public partial class CedarPlankedFishItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Cedar Planked Fish"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish cooked with herbs on a cedar plank."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 7, Protein = 15, Vitamins = 5};
        public override float Calories                          { get { return 1800; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 2)]    
    public partial class CedarPlankedFishRecipe : Recipe
    {
        public CedarPlankedFishRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<CedarPlankedFishItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<FishFiletItem>(typeof(AdvancedCookingSkill), 15, AdvancedCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<PlantFibersItem>(typeof(AdvancedCookingSkill), 15, AdvancedCookingSkill.MultiplicativeStrategy),
				new CraftingElement<BoardItem>(typeof(AdvancedCookingSkill), 9, AdvancedCookingSkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(CedarPlankedFishRecipe), Item.Get<CedarPlankedFishItem>().UILink(), 5, typeof(AdvancedCookingSkill)); 
            this.Initialize(Localizer.DoStr("Cedar Planked Fish"), typeof(CedarPlankedFishRecipe));
            CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}