namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(500)]                                          
    public partial class ClamRiceItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Clam with Tomato Sauce and Rice"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Tasty Clams with Tomato-Rice Sauce."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 5, Fat = 15, Protein = 13, Vitamins = 10};
        public override float Calories                          { get { return 1200; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 4)]    
    public partial class ClamRiceRecipe : Recipe
    {
        public ClamRiceRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ClamRiceItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<ClamItem>(typeof(AdvancedCookingSkill), 10, AdvancedCookingSkill.MultiplicativeStrategy),
                new CraftingElement<TomatoSauceItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy),
                new CraftingElement<RiceItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy),
                new CraftingElement<InfusedOilItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy), 
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(ClamRiceRecipe), Item.Get<ClamRiceItem>().UILink(), 20, typeof(AdvancedCookingSkill)); 
            this.Initialize(Localizer.DoStr("Clam with Tomato Sauce and Rice"), typeof(ClamRiceRecipe));
            CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}