namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(900)]                                          
    public partial class FishCurryItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Fish-Curry"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Sharp Fishly Curry"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 14, Fat = 12, Protein = 10, Vitamins = 9};
        public override float Calories                          { get { return 900; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class FishCurryRecipe : Recipe
    {
        public FishCurryRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FishCurryItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<FishFiletItem>(typeof(AdvancedCookingSkill), 10, AdvancedCookingSkill.MultiplicativeStrategy),
                new CraftingElement<FlourItem>(typeof(AdvancedCookingSkill), 10, AdvancedCookingSkill.MultiplicativeStrategy), 
			    new CraftingElement<RiceItem>(typeof(AdvancedCookingSkill), 15, AdvancedCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<InfusedOilItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy), 
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(FishCurryRecipe), Item.Get<FishCurryItem>().UILink(), 10, typeof(AdvancedCookingSkill)); 
            this.Initialize(Localizer.DoStr("Fish-Curry"), typeof(FishCurryRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}