namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(500)]                                          
    public partial class FishKebabItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Fish Kebab"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Cooked fish on a kebab."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 8, Protein = 6, Vitamins = 6};
        public override float Calories                          { get { return 600; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCampfireCookingSkill), 3)]    
    public partial class FishKebabRecipe : Recipe
    {
        public FishKebabRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FishKebabItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<RawFishItem>(typeof(AdvancedCampfireCookingSkill), 5, AdvancedCampfireCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<PlantFibersItem>(typeof(AdvancedCampfireCookingSkill), 5, AdvancedCampfireCookingSkill.MultiplicativeStrategy),
				new CraftingElement<WoodPulpItem>(typeof(AdvancedCampfireCookingSkill), 3, AdvancedCampfireCookingSkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(FishKebabRecipe), Item.Get<FishKebabItem>().UILink(), 5, typeof(AdvancedCampfireCookingSkill)); 
            this.Initialize(Localizer.DoStr("Fish Kebab"), typeof(FishKebabRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}