namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(500)]                                          
    public partial class FishStewItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Fish Stew"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish, herbs, and various vegetables cooked in to a stew."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 10, Fat = 11, Protein = 11, Vitamins = 8};
        public override float Calories                          { get { return 1400; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCampfireCookingSkill), 4)]    
    public partial class FishStewRecipe : Recipe
    {
        public FishStewRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FishStewItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<RawFishItem>(typeof(AdvancedCampfireCookingSkill), 15, AdvancedCampfireCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<AcornPowderItem>(typeof(AdvancedCampfireCookingSkill), 6, AdvancedCampfireCookingSkill.MultiplicativeStrategy),
				new CraftingElement<CamasBulbItem>(typeof(AdvancedCampfireCookingSkill), 10, AdvancedCampfireCookingSkill.MultiplicativeStrategy),
				new CraftingElement<CornItem>(typeof(AdvancedCampfireCookingSkill), 10, AdvancedCampfireCookingSkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(FishStewRecipe), Item.Get<FishStewItem>().UILink(), 5, typeof(AdvancedCampfireCookingSkill)); 
            this.Initialize(Localizer.DoStr("Fish Stew"), typeof(FishStewRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}