namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;

    
    [Serialized]
    [Weight(900)]                                          
    public partial class FriedFishItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Fried Fish and Wan-Tan"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fried Fish with Sweet Camas and Wan-Tan"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 15, Fat = 10, Protein = 8, Vitamins = 9};
        public override float Calories                          { get { return 900; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class FriedFishRecipe : Recipe
    {
        public FriedFishRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FriedFishItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<FishFiletItem>(typeof(AdvancedCookingSkill), 12, AdvancedCookingSkill.MultiplicativeStrategy),
                new CraftingElement<FlourItem>(typeof(AdvancedCookingSkill), 8, AdvancedCookingSkill.MultiplicativeStrategy), 
			    new CraftingElement<CamasBulbItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<OilItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy), 
				new CraftingElement<CornmealItem>(typeof(AdvancedCookingSkill), 5, AdvancedCookingSkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(FriedFishRecipe), Item.Get<FriedFishItem>().UILink(), 10, typeof(AdvancedCookingSkill)); 
            this.Initialize(Localizer.DoStr("Fried Fish and Wan-Tan"), typeof(FriedFishRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}